function [GeoC,GeoD,SystemStates,LocalDensity,LocalDensity2,LocalDensity3,LocalDensityVar,LocalDensityVar2,LocalDensityVar3,percapGrowth,Time,sampleTimes]=SimulatePatch_SimpleInteract(numTimes,GeoC,GeoD,SystemStates,LocalDensity,LocalDensity2,LocalDensity3,LocalDensityVar,LocalDensityVar2,LocalDensityVar3,percapGrowth,WorldHeight,WorldWidth,Parameters,WeightOrigin,WeightAdjacent,Weight2ndNeighbour,Time,sampleTimes,numCells,Map,MapType)


%Simulate.m
%Obtain system state and ancillary variables after time is incremented by
%numTimes (this many time steps)

%Edward Wong, Nov 9, 20tt
%update Aug 25: added local density tracking with once-removed neighbours
%(t2 neighbours in total)
%updated 4/29/14: use updatePatchGeo_simple for a simplified model
%updated 5/13/14: new simple interaction model

MoveCount=[0 0]; %reset movement counts
MigrationCount=[0 0]; %reset migration counts

%run simulation
for i=1:numTimes  %   # of times to repeat simulation before measurements
    [GeoC,GeoD,MigrationCount,MoveCount] = updatePatchGeo_SimpleInteract(GeoC,GeoD,MigrationCount,MoveCount,Parameters,WorldHeight,WorldWidth,Map,MapType);
end




%update time:
Time=Time+numTimes;
sampleTimes=[sampleTimes,Time];
sampleTimeStep=size(sampleTimes,2);


%update state measurements:
numD=sum(sum(sum(GeoD)));
numC=sum(sum(sum(GeoC)));
numCD=numC+numD;


SystemStates=[SystemStates, [numD/numCells, numC/numCells, numCD/numCells, MoveCount(1)/numD, MoveCount(2)/numC, MigrationCount(1)/numD, MigrationCount(2)/numC]'];
% row 1 = defector global density (D)(avg abundance per cell)
% row 2 = cooperator global density (C)
% row 3 = total bacteria abundance (C+D)
% row 4 = average defector movement rate
% row 5 = average cooperator movement rate
% row 6 = average defector migration rate (between patches)
% row 7 = average cooperator migration rate
SystemStates=double(SystemStates);


%update ancillary measurements:
%compute local densities method t (interaction kernel=origin patch)
xcc=cell(3,1); %first index indicates kernel number, second index indicates time
xcd=cell(3,1);
xdc=cell(3,1);
xdd=cell(3,1);
xc=zeros(12,1);
xd=zeros(12,1);

for x=1:WorldWidth
    for y=1:WorldHeight
        if Map(y,x)<=110
            xc(Map(y,x)/10+1)=xc(Map(y,x)/10+1)+GeoC(y,x); %add individual count to meta-patch (index)
            xd(Map(y,x)/10+1)=xd(Map(y,x)/10+1)+GeoD(y,x);
        end
        for i=1:GeoC(y,x) %for each cooperator at the (y,x) location, add xcc and xcd values
            for k=1:2
                xcc{k,1}=[xcc{k,1} (GeoC(y,x)-1)*WeightOrigin(k)];
                xcd{k,1}=[xcd{k,1} (GeoD(y,x))*WeightOrigin(k)];
            end
            
            for dir=1:4 %for local density with extended neighbourhood, weight 4 adjacent cells
                [xA,yA] = nextPatchCell(x,y,dir,WorldHeight,WorldWidth,Map,MapType);
                for k=1:2
                    xcc{k,1}(end)=xcc{k,1}(end)+GeoC(yA,xA)*WeightAdjacent(k);
                    xcd{k,1}(end)=xcd{k,1}(end)+GeoD(yA,xA)*WeightAdjacent(k);
                end
            end
            for dir=1:8 %for local density with extended neighbourhood, weight 8 once-removed neighbour cells by remaining fraction and add this weighted number of individuals to Xxtot2
                [xA,yA] = next2PatchCell(x,y,dir,WorldHeight,WorldWidth,Map,MapType);
                for k=1:2
                    xcc{k,1}(end)=xcc{k,1}(end)+GeoC(yA,xA)*Weight2ndNeighbour(k);
                    xcd{k,1}(end)=xcd{k,1}(end)+GeoD(yA,xA)*Weight2ndNeighbour(k);
                end
            end
        end
        for i=1:GeoD(y,x) %for each defector at the (y,x) location, add xcc and xcd values
            for k=1:2
                xdc{k,1}=[xdc{k,1} (GeoC(y,x))*WeightOrigin(k)];
                xdd{k,1}=[xdd{k,1} (GeoD(y,x)-1)*WeightOrigin(k)];
            end
            
            for dir=1:4 %for local density with extended neighbourhood, weight 4 adjacent cells
                [xA,yA] = nextPatchCell(x,y,dir,WorldHeight,WorldWidth,Map,MapType);
                for k=1:2
                    xdc{k,1}(end)=xdc{k,1}(end)+GeoC(yA,xA)*WeightAdjacent(k);
                    xdd{k,1}(end)=xdd{k,1}(end)+GeoD(yA,xA)*WeightAdjacent(k);
                end
            end
            for dir=1:8 %for local density with extended neighbourhood, weight 8 once-removed neighbour cells by remaining fraction and add this weighted number of individuals to Xxtot2
                [xA,yA] = next2PatchCell(x,y,dir,WorldHeight,WorldWidth,Map,MapType);
                for k=1:2
                    xdc{k,1}(end)=xdc{k,1}(end)+GeoC(yA,xA)*Weight2ndNeighbour(k);
                    xdd{k,1}(end)=xdd{k,1}(end)+GeoD(yA,xA)*Weight2ndNeighbour(k);
                end
            end
        end
    end
end

for mpatch=1:12
    xcc{3,1}=[xcc{3,1} ones(1,xc(mpatch))*max(xc(mpatch)-1,0)*WeightOrigin(3)];
    xcd{3,1}=[xcd{3,1} ones(1,xc(mpatch))*xd(mpatch)*WeightOrigin(3)];
    xdc{3,1}=[xdc{3,1} ones(1,xd(mpatch))*xc(mpatch)*WeightOrigin(3)];
    xdd{3,1}=[xdd{3,1} ones(1,xd(mpatch))*max(xd(mpatch)-1,0)*WeightOrigin(3)];
end


for k=1:3
    Xcc_mean(k)=mean(xcc{k,1});
    Xcd_mean(k)=mean(xcd{k,1});
    Xdc_mean(k)=mean(xdc{k,1});
    Xdd_mean(k)=mean(xdd{k,1});
    
    Xcc_var(k)=var(xcc{k,1});
    Xcd_var(k)=var(xcd{k,1});
    Xdc_var(k)=var(xdc{k,1});
    Xdd_var(k)=var(xdd{k,1});
end

LocalDensity=[LocalDensity, [Xdd_mean(1) Xdc_mean(1) Xcd_mean(1) Xcc_mean(1)]']; % column # = SAMPLE time T
% row t = defector local density around defector (Dd)
% row 2 = cooperator local density around defector (Cd)
% row 3 = defector local density around cooperator (Dc)
% row 4 = cooperator local density around cooperator (Cc)
LocalDensity2=[LocalDensity2, [Xdd_mean(2) Xdc_mean(2) Xcd_mean(2) Xcc_mean(2)]'];
LocalDensity3=[LocalDensity3, [Xdd_mean(3) Xdc_mean(3) Xcd_mean(3) Xcc_mean(3)]'];

LocalDensityVar=[LocalDensityVar, [Xdd_var(1) Xdc_var(1) Xcd_var(1) Xcc_var(1)]'];
LocalDensityVar2=[LocalDensityVar2, [Xdd_var(2) Xdc_var(2) Xcd_var(2) Xcc_var(2)]'];
LocalDensityVar3=[LocalDensityVar3, [Xdd_var(3) Xdc_var(3) Xcd_var(3) Xcc_var(3)]'];


%update growth rate estimates
if(SystemStates(1,sampleTimeStep-1)>0 && SystemStates(1,sampleTimeStep)>0)
    rd=log(SystemStates(1,sampleTimeStep))-log(SystemStates(1,sampleTimeStep-1)); %defector per capita growth rate OR is this growth rate?
else
    rd=0;
end
if(SystemStates(2,sampleTimeStep-1)>0 && SystemStates(2,sampleTimeStep)>0)
    rc=log(SystemStates(2,sampleTimeStep))-log(SystemStates(2,sampleTimeStep-1)); %defector per capita growth rate
else
    rc=0;
end
percapGrowth=[percapGrowth, [rd, rc]']; % column # = SAMPLE time T
% row 1 = defector per capita growth rate (dD/Ddt)=ln(D(T)/D(T-dT))
% row 2 = cooperator per capita growth rate (dC/Cdt)=ln(C(T)/C(T-dT))

