function[GeoC,GeoD,SystemStates,LocalDensity,LocalDensity2,LocalDensity3,LocalDensityVar,LocalDensityVar2,LocalDensityVar3,GeoCSeries,GeoDSeries,WeightOrigin,WeightAdjacent,Weight2ndNeighbour,numCells]=initializePatch_SimpleInteract(GeoC,GeoD,SystemStates,LocalDensity,LocalDensity2,LocalDensity3,LocalDensityVar,LocalDensityVar2,LocalDensityVar3,GeoCSeries,GeoDSeries,WorldHeight,WorldWidth,Map,MapType,initC,initD)
% initializePatch
% Initialize patchy world maps
% Edward Wong, Nov 9, 2011
% Mac version
%updated 5/13/14: new simple interaction model

numCells=0; %number of habitable cells
numCors=0; %number of corridors
% define parameters

%Interaction kernel 1:
WeightOrigin(1)=1; %interaction kernel weighting of original patch around focal individual
WeightAdjacent(1)=(1-WeightOrigin(1))/6; %interaction kernel weighting of each of 4 adjacent patches around focal individual
Weight2ndNeighbour(1)=(1-WeightOrigin(1))/24; %interaction kernel weighting of each of 8 once-removed patches around focal individual
%check that weights add up to 1:
TotalCellWeights(1)=WeightOrigin(1)+WeightAdjacent(1)*4+Weight2ndNeighbour(1)*8;

%Interaction kernel 2:
WeightOrigin(2)=0.2; %interaction kernel weighting of original patch around focal individual
WeightAdjacent(2)=(1-WeightOrigin(2))/6; %interaction kernel weighting of each of 4 adjacent patches around focal individual
Weight2ndNeighbour(2)=(1-WeightOrigin(2))/24; %interaction kernel weighting of each of 8 once-removed patches around focal individual
%check that weights add up to 1:
TotalCellWeights(2)=WeightOrigin(2)+WeightAdjacent(2)*4+Weight2ndNeighbour(2)*8;

%Interaction kernel 3:
%MPatchSize=[]; %find average size of habitat-scale meta-patch
WeightOrigin(3)=0; %interaction kernel weighting of original patch (and all adjacent patches in habitat-scale meta-patch) around focal individual


%map interaction kernel1:
IntKernel1=zeros(7);
IntKernel1(4,4)=WeightOrigin(1);
for dir=1:4%for local density with extended neighbourhood, weight 4 adjacent patches
    [xA,yA] = nextCell(4,4,dir,7,7);
    IntKernel1(yA,xA)=WeightAdjacent(1);
end
for dir=1:8 %for local density with extended neighbourhood, weight 8 once-removed neighbour patches
    [xA,yA] = next2Cell(4,4,dir,7,7);
    IntKernel1(yA,xA)=Weight2ndNeighbour(1);
end
%map interaction kernel2:
IntKernel2=zeros(7);
IntKernel2(4,4)=WeightOrigin(2);
for dir=1:4%for local density with extended neighbourhood, weight 4 adjacent patches
    [xA,yA] = nextCell(4,4,dir,7,7);
    IntKernel2(yA,xA)=WeightAdjacent(2);
end
for dir=1:8 %for local density with extended neighbourhood, weight 8 once-removed neighbour patches
    [xA,yA] = next2Cell(4,4,dir,7,7);
    IntKernel2(yA,xA)=Weight2ndNeighbour(2);
end
%map interaction kernel3:
% IntKernel3=zeros(7);
% IntKernel3(4,4)=WeightOrigin(3);
% for dir=1:4%for local density with extended neighbourhood, weight 4 adjacent patches
%     [xA,yA] = nextCell(4,4,dir,7,7);
%     IntKernel3(yA,xA)=WeightAdjacent(3);
% end
% for dir=1:8 %for local density with extended neighbourhood, weight 8 once-removed neighbour patches
%     [xA,yA] = next2Cell(4,4,dir,7,7);
%     IntKernel3(yA,xA)=Weight2ndNeighbour(3);
% end

subplot(1,2,1); bar3(IntKernel1,1,'-.w')
title('Interaction Kernel 1')
zlabel('Weight')
subplot(1,2,2); bar3(IntKernel2,1,'-.w')
title('Interaction Kernel 2')
zlabel('Weight')
% subplot(1,3,3); bar3(IntKernel3,1,'-.w')
% title('Interaction Kernel 3')
% zlabel('Weight')



%initialize random number of cooperators and defectors in each cell
%initC,initD are the initial mean cooperator and defector densities, each
%independently Poisson distributed at each habitable cell
for x=1:WorldWidth
    for y=1:WorldHeight
        if (Map(y,x)~=255) %check for habitable cell (black=inhabitable=255)
            numCells=numCells+1;
            if (Map(y,x)==140 || Map(y,x)==170)
                numCors=numCors+1;
            end
            %            MPatchSize(Map(y,x)/10+1)=MPatchSize(Map(y,x)/10+1)+1; %count number of patches in meta-patch (according to the 12 map ID, they are 0, 10,...,110)
            %             localCD=floor(5.*rand(1,1));
            %             localC=floor((localCD+1).*rand(1,1));
            %             GeoC(y,x)=localC;
            %             GeoD(y,x)=localCD-localC;
            GeoC(y,x)=poissrnd(initC);
            GeoD(y,x)=poissrnd(initD);
        end
    end
end
WeightOrigin(3)=12/(numCells-numCors);
%numCells



%update GeoSeries
GeoCSeries=cat(3,GeoCSeries,GeoC);
GeoDSeries=cat(3,GeoDSeries,GeoD);


%update state measurements:
numD=sum(sum(GeoD));
numC=sum(sum(GeoC));
numCD=numC+numD;

SystemStates=[SystemStates, [numD/numCells, numC/numCells, numCD/numCells,0,0,0,0]'];
% row 1 = defector global density (D)(avg abundance per cell)
% row 2 = cooperator global density (C)
% row 3 = average siderophore concentration (S) (avg concentration per cell)
% row 4 = total bacteria density (C+D)
% row 5 = average defector movement rate
% row 6 = average cooperator movement rate
% row 7 = number of successful defector migrations, per unit area, from one patch to another
% row 8 = number of successful cooperator migrations, per unit area, from one patch to another


%update initial ancillary measurements:
%compute local densities
xcc=cell(3,1); %first index indicates kernel number, second index indicates time
xcd=cell(3,1);
xdc=cell(3,1);
xdd=cell(3,1);
xc=zeros(12,1);
xd=zeros(12,1);

for x=1:WorldWidth
    for y=1:WorldHeight
        if Map(y,x)<=110
            xc(Map(y,x)/10+1)=xc(Map(y,x)/10+1)+GeoC(y,x); %add individual count to meta-patch (index)
            xd(Map(y,x)/10+1)=xd(Map(y,x)/10+1)+GeoD(y,x);
        end
        for i=1:GeoC(y,x) %for each cooperator at the (y,x) location, add xcc and xcd values
            for k=1:2
                xcc{k,1}=[xcc{k,1} (GeoC(y,x)-1)*WeightOrigin(k)];
                xcd{k,1}=[xcd{k,1} (GeoD(y,x))*WeightOrigin(k)];
            end
            
            for dir=1:4 %for local density with extended neighbourhood, weight 4 adjacent cells
                [xA,yA] = nextPatchCell(x,y,dir,WorldHeight,WorldWidth,Map,MapType);
                for k=1:2
                    xcc{k,1}(end)=xcc{k,1}(end)+GeoC(yA,xA)*WeightAdjacent(k);
                    xcd{k,1}(end)=xcd{k,1}(end)+GeoD(yA,xA)*WeightAdjacent(k);
                end
            end
            for dir=1:8 %for local density with extended neighbourhood, weight 8 once-removed neighbour cells by remaining fraction and add this weighted number of individuals to Xxtot2
                [xA,yA] = next2PatchCell(x,y,dir,WorldHeight,WorldWidth,Map,MapType);
                for k=1:2
                    xcc{k,1}(end)=xcc{k,1}(end)+GeoC(yA,xA)*Weight2ndNeighbour(k);
                    xcd{k,1}(end)=xcd{k,1}(end)+GeoD(yA,xA)*Weight2ndNeighbour(k);
                end
            end
        end
        for i=1:GeoD(y,x) %for each defector at the (y,x) location, add xcc and xcd values
            for k=1:2
                xdc{k,1}=[xdc{k,1} (GeoC(y,x))*WeightOrigin(k)];
                xdd{k,1}=[xdd{k,1} (GeoD(y,x)-1)*WeightOrigin(k)];
            end
            
            for dir=1:4 %for local density with extended neighbourhood, weight 4 adjacent cells
                [xA,yA] = nextPatchCell(x,y,dir,WorldHeight,WorldWidth,Map,MapType);
                for k=1:2
                    xdc{k,1}(end)=xdc{k,1}(end)+GeoC(yA,xA)*WeightAdjacent(k);
                    xdd{k,1}(end)=xdd{k,1}(end)+GeoD(yA,xA)*WeightAdjacent(k);
                end
            end
            for dir=1:8 %for local density with extended neighbourhood, weight 8 once-removed neighbour cells by remaining fraction and add this weighted number of individuals to Xxtot2
                [xA,yA] = next2PatchCell(x,y,dir,WorldHeight,WorldWidth,Map,MapType);
                for k=1:2
                    xdc{k,1}(end)=xdc{k,1}(end)+GeoC(yA,xA)*Weight2ndNeighbour(k);
                    xdd{k,1}(end)=xdd{k,1}(end)+GeoD(yA,xA)*Weight2ndNeighbour(k);
                end
            end
        end
    end
end

for mpatch=1:12
    xcc{3,1}=[xcc{3,1} ones(1,xc(mpatch))*max(xc(mpatch)-1,0)*WeightOrigin(3)];
    xcd{3,1}=[xcd{3,1} ones(1,xc(mpatch))*xd(mpatch)*WeightOrigin(3)];
    xdc{3,1}=[xdc{3,1} ones(1,xd(mpatch))*xc(mpatch)*WeightOrigin(3)];
    xdd{3,1}=[xdd{3,1} ones(1,xd(mpatch))*max(xd(mpatch)-1,0)*WeightOrigin(3)];
end


for k=1:3
    Xcc_mean(k)=mean(xcc{k,1});
    Xcd_mean(k)=mean(xcd{k,1});
    Xdc_mean(k)=mean(xdc{k,1});
    Xdd_mean(k)=mean(xdd{k,1});
    
    Xcc_var(k)=var(xcc{k,1});
    Xcd_var(k)=var(xcd{k,1});
    Xdc_var(k)=var(xdc{k,1});
    Xdd_var(k)=var(xdd{k,1});
end

LocalDensity=[LocalDensity, [Xdd_mean(1) Xdc_mean(1) Xcd_mean(1) Xcc_mean(1)]']; % column # = SAMPLE time T
% row 1 = defector local density around defector (Dd)
% row 2 = cooperator local density around defector (Cd)
% row 3 = defector local density around cooperator (Dc)
% row 4 = cooperator local density around cooperator (Cc)
LocalDensity2=[LocalDensity2, [Xdd_mean(2) Xdc_mean(2) Xcd_mean(2) Xcc_mean(2)]'];
LocalDensity3=[LocalDensity3, [Xdd_mean(3) Xdc_mean(3) Xcd_mean(3) Xcc_mean(3)]'];

LocalDensityVar=[LocalDensityVar, [Xdd_var(1) Xdc_var(1) Xcd_var(1) Xcc_var(1)]'];
LocalDensityVar2=[LocalDensityVar2, [Xdd_var(2) Xdc_var(2) Xcd_var(2) Xcc_var(2)]'];
LocalDensityVar3=[LocalDensityVar3, [Xdd_var(3) Xdc_var(3) Xcd_var(3) Xcc_var(3)]'];
