function [newGeoC,newGeoD,MigrationCount,MoveCount] = updatePatchGeo_SimpleInteract(GeoC,GeoD,MigrationCount,MoveCount,Parameters,WorldHeight,WorldWidth,Map,MapType)

%matrices with prefix "new" represent states of next time step.  Original
%function inputs are of current time t and are not changed.
%Edward Wong May 8, 2011
%Modified 7/26/13 - corridors have no siderophores
%Mac version
%updated 5/13/14: new simple interaction model

sampleTimeSteps=100; %increase to reduce error associated with Euler's method of discretizing continuous model parameters

newGeoC=GeoC;
newGeoD=GeoD;

%read parameters:
b=Parameters(1)/sampleTimeSteps; %birth rate
d=Parameters(2)/sampleTimeSteps;%death rate
k=Parameters(3)/sampleTimeSteps; %competition coefficient
a=Parameters(4)/sampleTimeSteps; %benefit
c=Parameters(5)/sampleTimeSteps; %cost
m=Parameters(6);%/sampleTimeSteps; %movement rate
%Parameters=[d,ISd,ISb0,K,bmax,mmax,ISm,quorum,QS,tumble,mcost,ISe,Ssat,pmax,pcost,acq,conv,metabolicCost,leach,Sdiffuse,DS];


%update cooperator & defector states
%sequence: birth, death, move
for x=1:WorldWidth
    for y=1:WorldHeight
        PatchID=double(Map(y,x));
        numC=GeoC(y,x);
        numD=GeoD(y,x);
        CDX=numC+numD;
        if(CDX>0) %individuals present
            if(numC>0) %for cooperators
                %birth affected by help, competition, and cost
                newGeoC(y,x)=newGeoC(y,x)+max(binornd(1,b+a*(GeoC(y,x)-1)-k*(CDX-1)-c),0);
                %death
                numDeathC=binornd(GeoC(y,x),d);
                newGeoC(y,x)=newGeoC(y,x)-numDeathC;
                %move
                numCmove=binornd(GeoC(y,x)-numDeathC,m); %number of movers
                for n=1:numCmove
                    direction=ceil(4.*rand(1,1));
                    [xnext,ynext] = nextPatchCell(x,y,direction,WorldHeight,WorldWidth,Map,MapType); %find coordinates of next cell
                    %probability of successfully moving into chosen direction
                    if(xnext~=WorldWidth+1) %chosen direction is impassable, bacterium stays
                        %otherwise move
                        newGeoC(y,x)=newGeoC(y,x)-1;
                        newGeoC(ynext,xnext)=newGeoC(ynext,xnext)+1;
                        MoveCount(2)=MoveCount(2)+1; %movement counted
                        nextPatchID=double(Map(ynext,xnext));
                        if(nextPatchID~=PatchID && (nextPatchID~=170 && nextPatchID~=140)) %there has been a migration if the current patch ID is different from previous and is not a corridor
                            MigrationCount(2)=MigrationCount(2)+1; %count migration event
                        end
                    end
                end
            end
            if(numD>0) %for defectors
                %birth affected by help, competition, and cost
                newGeoD(y,x)=newGeoD(y,x)+max(binornd(1,b+a*GeoC(y,x)-k*(CDX-1)),0);
                %death
                numDeathD=binornd(GeoD(y,x),d);
                newGeoD(y,x)=newGeoD(y,x)-numDeathD;
                %move
                numDmove=binornd(GeoD(y,x)-numDeathD,m); %number of movers
                for n=1:numDmove
                    direction=ceil(4.*rand(1,1));
                    [xnext,ynext] = nextPatchCell(x,y,direction,WorldHeight,WorldWidth,Map,MapType); %find coordinates of next cell
                    %probability of successfully moving into chosen direction
                    if(xnext~=WorldWidth+1) %chosen direction is impassable, bacterium stays
                        %otherwise move
                        newGeoD(y,x)=newGeoD(y,x)-1;
                        newGeoD(ynext,xnext)=newGeoD(ynext,xnext)+1;
                        MoveCount(1)=MoveCount(1)+1; %movement counted
                        nextPatchID=double(Map(ynext,xnext));
                        if(nextPatchID~=PatchID && (nextPatchID~=170 && nextPatchID~=140)) %there has been a migration if the current patch ID is different from previous and is not a corridor
                            MigrationCount(1)=MigrationCount(1)+1; %count migration event
                        end
                    end
                end
            end
        end
    end
end